@@ -89,7 +89,7 @@ OptionsRec options;
 
 static XtResource resources[] = {
   {"selection", "Selection", XtRString, sizeof(String),
-   Offset(selection_name), XtRString, "PRIMARY"},
+   Offset(selection_name), XtRString, "CLIPBOARD"},
   {"cutBuffer", "CutBuffer", XtRInt, sizeof(int),
    Offset(buffer), XtRImmediate, (XtPointer)0},
   {"debug", "Debug", XtRString, sizeof(String),
@@ -284,7 +284,7 @@ int main(int argc, char* argv[])
   box = XtCreateManagedWidget("box", boxWidgetClass, top, NULL, 0);
   dpy = XtDisplay(top);
    
-  selection = XInternAtom(dpy, "PRIMARY", 0);
+  selection = XInternAtom(dpy, options.selection_name, 0);
   options.selection = selection;
   buffer = 0;
 
